@@ -16,20 +16,20 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: vterdb.h,v 1.2 2003/05/05 23:23:46 nalin Exp $"
+#ident "$Id: vterdb.h,v 1.3 2003/05/28 23:45:09 nalin Exp $"
 
 #ifndef vte_rdbh_included
 #define vte_rdbh_included
 
-#include <glib.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
-double _vte_rdb_get_dpi(void);
-gboolean _vte_rdb_get_antialias(void);
-gboolean _vte_rdb_get_hinting(void);
-const char *_vte_rdb_get_rgba(void);
-const char *_vte_rdb_get_hintstyle(void);
+double _vte_rdb_get_dpi(GtkWidget *widget);
+gboolean _vte_rdb_get_antialias(GtkWidget *widget);
+gboolean _vte_rdb_get_hinting(GtkWidget *widget);
+const char *_vte_rdb_get_rgba(GtkWidget *widget);
+const char *_vte_rdb_get_hintstyle(GtkWidget *widget);
 
 G_END_DECLS
 
